==> better-admin-ui-vue-0.0.15.tgz: package/es/components/MixedInput/MixedInput.js <==
import _mergeJSXProps2 from "babel-helper-vue-jsx-merge-props";
import _mergeJSXProps from "babel-helper-vue-jsx-merge-props";

/**
 * @Date: 2020/11/23 9:41 下午
 * @Author: Fioanna
 * @Description: 组合输入建议框
 */
import AInput from 'ant-design-vue/es/input';
import ESelect from '../Select';
import ESuggestSelect from '../SuggestSelect';
import mixedInputProps from './types';
var AInputGroup = AInput.Group;
export default {
  name: 'EMixedInput',
  props: mixedInputProps,
  data: function data() {
    return {
      // 左边的选项值
      leftOption: {},
      // 双向绑定数据
      dValue: this.$props.value
    };
  },
  model: {
    props: 'value',
    event: 'change'
  },
  computed: {
    placeholder: function placeholder() {
      if (this.$data.leftOption.props && this.$data.leftOption.props.placeholder) {
        return this.$data.leftOption.props.placeholder;
      }

      return '请输入' + this.$data.leftOption.label;
    }
  },
  watch: {
    value: function value(newVal) {
      this.dValue = newVal || undefined;
    },
    dValue: function dValue(newVal) {
      if (this.value !== newVal) {
        // 当前数据和传入的值不同时，改变外面的值
        this.$emit('change', newVal, this.$data.leftOption.key);
      }
    }
  },
  created: function created() {
    if (this.$props.options && this.$props.options[0]) {
      this.$data.leftOption = this.$props.options[0];
    }

    this.$data.dValue = this.$props.value;
  },
  methods: {
    // 左边下拉选项变更
    _leftChange: function _leftChange(value, label, option) {
      if (this.$data.leftOption.value !== value) {
        this.$data.leftOption = option;
        this.dValue = undefined;
        this.$refs.suggestSelect && this.$refs.suggestSelect.resetSuggestList();
      }
    },
    _inputChange: function _inputChange(value, label, item) {
      if (label && item) {
        this.$emit('change', value, this.$data.leftOption.key, label, item);
      } else {
        this.$emit('change', value, this.$data.leftOption.key);
      }
    }
  },
  render: function render() {
    var _this = this;

    var h = arguments[0];
    var _this$$props = this.$props,
        disabled = _this$$props.disabled,
        options = _this$$props.options;
    var _this$$data$leftOptio = this.$data.leftOption,
        suggest = _this$$data$leftOptio.suggest,
        props = _this$$data$leftOptio.props,
        value = _this$$data$leftOptio.value;

    var handleInputChange = function handleInputChange(e) {
      _this._inputChange(e.target.value);
    };

    var handleSuggestChange = function handleSuggestChange(value, label, item) {
      _this.$data.dValue = value;

      _this._inputChange(value, label, item);
    };

    return h(AInputGroup, {
      attrs: {
        compact: true
      }
    }, [h(ESelect, {
      style: "width:40%",
      attrs: {
        options: options,
        value: value
      },
      on: {
        "change": this._leftChange
      }
    }), suggest ? h(ESuggestSelect, _mergeJSXProps([{
      ref: "suggestSelect",
      style: "width:60%;",
      attrs: {
        placeholder: this.placeholder,
        disabled: disabled,
        value: this.$data.dValue
      },
      on: {
        "change": handleSuggestChange
      }
    }, {
      props: props
    }])) : h(AInput, _mergeJSXProps2([{
      style: "width:60%;",
      attrs: {
        placeholder: this.placeholder,
        disabled: disabled,
        value: this.$data.dValue
      },
      on: {
        "change": handleInputChange
      }
    }, {
      props: props
    }]))]);
  }
};

==> better-admin-ui-vue-0.0.19.tgz: package/es/components/MixedInput/MixedInput.js <==
import _mergeJSXProps2 from "babel-helper-vue-jsx-merge-props";
import _mergeJSXProps from "babel-helper-vue-jsx-merge-props";

/**
 * @Date: 2020/11/23 9:41 下午
 * @Author: Fioanna
 * @Description: 组合输入建议框
 */
import AInput from 'ant-design-vue/es/input';
import ESelect from '../Select';
import ESuggestSelect from '../SuggestSelect';
import mixedInputProps from './types';
var AInputGroup = AInput.Group;
export default {
  name: 'EMixedInput',
  props: mixedInputProps,
  data: function data() {
    return {
      // 左边的选项值
      leftOption: {} // 双向绑定数据
      // dValue: this.$props.value

    };
  },
  // model: {
  //   props: 'value',
  //   event: 'change'
  // },
  computed: {
    placeholder: function placeholder() {
      if (this.$data.leftOption.props && this.$data.leftOption.props.placeholder) {
        return this.$data.leftOption.props.placeholder;
      }

      return '请输入' + this.$data.leftOption.label;
    }
  },
  // watch: {
  //   value (newVal) {
  //     this.dValue = newVal || undefined
  //   },
  //   dValue (newVal) {
  //     if (this.value !== newVal) {
  //       // 当前数据和传入的值不同时，改变外面的值
  //       this.$emit('change', newVal, this.$data.leftOption.key)
  //     }
  //   }
  // },
  created: function created() {
    if (this.$props.options && this.$props.options[0]) {
      this.$data.leftOption = this.$props.options[0];
    } // this.$data.dValue = this.$props.value

  },
  methods: {
    // 左边下拉选项变更
    _leftChange: function _leftChange(value, label, option) {
      if (this.$data.leftOption.value !== value) {
        this.$data.leftOption = option; // this.dValue = undefined

        this.$refs.suggestSelect && this.$refs.suggestSelect.resetSuggestList();
      }
    },
    _inputChange: function _inputChange(value, label, item) {
      if (label && item) {
        this.$emit('change', value, this.$data.leftOption.key, label, item);
      } else {
        this.$emit('change', value, this.$data.leftOption.key);
      }
    }
  },
  render: function render() {
    var _this = this;

    var h = arguments[0];
    var _this$$props = this.$props,
        disabled = _this$$props.disabled,
        options = _this$$props.options;
    var _this$$data$leftOptio = this.$data.leftOption,
        suggest = _this$$data$leftOptio.suggest,
        props = _this$$data$leftOptio.props,
        value = _this$$data$leftOptio.value;

    var handleInputChange = function handleInputChange(e) {
      _this._inputChange(e.target.value);
    };

    var handleSuggestChange = function handleSuggestChange(value, label, item) {
      // this.$data.dValue = value
      _this._inputChange(value, label, item);
    };

    return h(AInputGroup, {
      attrs: {
        compact: true
      }
    }, [h(ESelect, {
      style: "width:40%",
      attrs: {
        options: options,
        value: value
      },
      on: {
        "change": this._leftChange
      }
    }), suggest ? h(ESuggestSelect, _mergeJSXProps([{
      ref: "suggestSelect",
      style: "width:60%;",
      attrs: {
        placeholder: this.placeholder,
        disabled: disabled // value={this.$data.dValue}

      },
      on: {
        "change": handleSuggestChange
      }
    }, {
      props: props
    }])) : h(AInput, _mergeJSXProps2([{
      style: "width:60%;",
      attrs: {
        placeholder: this.placeholder,
        disabled: disabled // value={this.$data.dValue}

      },
      on: {
        "change": handleInputChange
      }
    }, {
      props: props
    }]))]);
  }
};
